@@ -252,7 +252,7 @@ class Database:
                 # table.add_rows([[key, match_val[value]] if value in match_val
                 #                     else [key, '?'] for key, value in par_dict.items()])
 
-                symbol = {"start": "S", "wait": "W", "end": "F", "error": "E"}
+                symbol = {"start": "S", "wait": "W", "end": "F", "error": "E", "kill": "K"}
                 table.add_rows([(key, symbol.get(val, '?'))
                                 for key, val in par_dict.items()])
 
@@ -270,14 +270,14 @@ class Database:
 
                 # print("S: Submitted, F: Finished, W: Wait, E: Error")
                 # print(table)
-                status_string.append("S: Submitted, F: Finished, W: Wait, E: Error")
+                status_string.append("S: Submitted, F: Finished, W: Wait, E: Error, K: Killed")
                 status_string.append(table)
                 return status_string
 
             # case with progress variable
             table = PrettyTable()
             table.field_names = ["Workflow number", "Status", 'Progress']
-            symbol = {"start": "S", "wait": "W", "end": "F", "error": "E"}
+            symbol = {"start": "S", "wait": "W", "end": "F", "error": "E", "kill": "K"}
             _string =  [(key, symbol.get(val, '?'), 'NA')
                                 for key, val in par_dict.items()]
             main_dir = os.getcwd()
@@ -304,7 +304,7 @@ class Database:
                 _string[ii] = (_string[ii][0], _string[ii][1], tmp_progress)
                 os.chdir(main_dir)
             table.add_rows(_string)
-            status_string.append("S: Submitted, F: Finished, W: Wait, E: Error")
+            status_string.append("S: Submitted, F: Finished, W: Wait, E: Error, K: Killed")
             status_string.append(table)
             return status_string
 
@@ -331,9 +331,9 @@ class Database:
                 else:
                     value_list.append('Submitted')
             value_list = [str(ii)] + value_list
-            
+
             return value_list
-            
+
         # print()
         # print("Status for chain %s " % (chain_name))
         status_string.append("Status for chain %s " % (chain_name))
@@ -371,6 +371,7 @@ class Database:
         for ii, loop in enumerate(database[chain_name]):
             value_list = []
 
+            #TODO: check that correctly done as we check the current loop -> latest active
             # Separate handling of first loop situation
             if self.get_current_loop_val('loop_count') == 1:
                 if not 'condition_reached' in loop:
@@ -461,6 +462,8 @@ class Database:
                                     tmp_path = './'
                                 value_list.append(tmp_path)
                             except KeyError as excep:
+                                # assume it's in the main directory, perhaps consider 'NA' instead
+                                value_list.append('./')
                                 continue
                         else:
                             value_list.append("NA")
@@ -468,7 +471,6 @@ class Database:
                 table.field_names = ["Loop"] + names_keys
                 table.add_row(value_list)
 
-                # print(loop["end_message"])
                 try:
                     if loop["end_message"] is not None:
                         end_message = customise_end_message(self, ii, loop["end_message"])
