@@ -155,49 +155,96 @@ def lemmings_cli(workflow, status, yaml, noverif, restart, parallel):
 
 @cli.command('kill')
 def lemmings_kill():
-    """Kill the current job and pjob of lemmings"""
+    """ Kill the current job and pjob of lemmings
+
+        In farming mode, if command called from the main directory
+        all running Workflows will be killed.
+    """
     import os
     import yaml
     from lemmings_hpc.chain.database import Database
     import subprocess as sbp
 
+    parallel_kill = False
+
     database = Database()
-    # chain_name = database.latest_chain_name
 
     env_var = dict(os.environ)
-    try:
+    try: # need to know how to kill jobs
         machine_path = env_var["LEMMINGS_MACHINE"]
     except KeyError:
         print("No LEMMINGS_MACHINE environment variable specified")
         return
 
+    try: # check if parallel mode
+        par_dict, = database.get_current_loop_val('parallel_runs')
+        kill_confirm = input("Are you sure you want to kill all lemmings Workflows? (yes/no)  ")
+        if kill_confirm != 'yes':
+            return
+        parallel_kill = True
+    except KeyError:
+        pass
+
     with open(machine_path) as fin:
         machine_dict = yaml.load(fin, Loader=yaml.SafeLoader)
 
-    try:
-        job_id = database.get_loop_val('job_id', 0) #latest loop
-        pjob_id = database.get_loop_val('pjob_id', 0)
-    except KeyError:
-        print("No job and / or post job to kill in current database loop")
+    def kill_chain(database):
+        try:
+            job_id = database.get_loop_val('job_id', 0) #latest loop
+            pjob_id = database.get_loop_val('pjob_id', 0)
+        except KeyError:
+            print("No job and / or post job to kill in current database loop")
+            return
+
+        print("Killing the current job and post-job...")
+
+        try:
+            #print(type(machine_dict['commands']['cancel']))
+            machine_dict['commands']['cancel']
+        except KeyError:
+            print("No 'cancel' command specified in the machine file")
+            return
+
+        sbp.run([machine_dict['commands']['cancel'],
+                job_id],
+                stdout=sbp.PIPE)
+        print("   job  "+ str(job_id) + " was killed")
+        sbp.run([machine_dict['commands']['cancel'],
+                pjob_id],
+                stdout=sbp.PIPE)
+        print("   pjob "+ str(pjob_id) + " was killed")
+
+    if parallel_kill:
+        # we have to do two things:
+        #   1) update status from jobs that were waiting to killed "K"
+        #   2) kill the jobs that are running
+
+        # check first if there is anything chain to kill
+        workflows_to_kill = [key for key, val in par_dict.items() if val == 'start']
+        if not workflows_to_kill: 
+            print("No workflows to kill")
+            return
+
+        par_dict = dict([(key,val) if val != 'wait' else (key, 'kill')
+                            for key, val in par_dict.items() ])
+        database.update_current_loop('parallel_runs',[par_dict])
+
+        main_dir = os.getcwd()
+        for wf_dir in workflows_to_kill:
+            os.chdir(wf_dir)
+            kill_chain(database)
+            os.chdir(main_dir)
+
+        # now we'll update the database as we successfully killed the active chains
+        par_dict = dict([(key,val) if val != 'start' else (key, 'kill')
+                            for key, val in par_dict.items() ])
+        database.update_current_loop('parallel_runs',[par_dict])
         return
 
-    print("Killing the current job and post-job...")
+    # for non farming case
+    kill_chain(database)
 
-    try:
-        #print(type(machine_dict['commands']['cancel']))
-        machine_dict['commands']['cancel']
-    except KeyError:
-        print("No 'cancel' command specified in the machine file")
-        return
 
-    sbp.run([machine_dict['commands']['cancel'],
-             job_id],
-            stdout=sbp.PIPE)
-    print("   job  "+ str(job_id) + " was killed")
-    sbp.run([machine_dict['commands']['cancel'],
-             pjob_id],
-            stdout=sbp.PIPE)
-    print("   pjob "+ str(pjob_id) + " was killed")
 
 
 
@@ -374,5 +421,26 @@ def lemmings_clean(database):
         remove(path)
 
 
+@cli.command('info')
+@click.option("--queues", "-q", is_flag=True,
+              help="Get {machine}.yml queues info")
+
+def lemmings_info(queues):
+    import os
+    import yaml
+    if queues:
+        env_var = dict(os.environ)
+        try:
+            machine_path = env_var["LEMMINGS_MACHINE"]
+        except KeyError:
+            print("No LEMMINGS_MACHINE environment variable specified")
+            return
+
+        print("Path to {machine}.yml file", machine_path)
+        with open(machine_path) as yaml_in:
+            tmp = yaml.load(yaml_in, Loader=yaml.FullLoader)
+            print("Queues available in {machine}.yml file:")
+            for line in tmp['queues']:
+                print("\t"+line)
 #Main function called by setup.py
 main = click.CommandCollection(sources=[cli], help="This is the help of lemmings")
